VooCollapseToggle class

Minimal collapse/expand toggle button for navigation drawer/rail.

A small bordered square button with a sidebar panel icon.

Inheritance

Constructors

VooCollapseToggle({Key? key, required bool isExpanded, required VoidCallback onToggle, IconData? expandedIcon, IconData? collapsedIcon, String? expandedTooltip, String? collapsedTooltip, Color? iconColor, Color? hoverColor})
const

Properties

collapsedIcon IconData?
Custom icon for collapsed state
final
collapsedTooltip String?
Tooltip for collapsed state
final
expandedIcon IconData?
Custom icon for expanded state
final
expandedTooltip String?
Tooltip for expanded state
final
hashCode int
The hash code for this object.
no setterinherited
hoverColor Color?
Custom icon color when hovered (uses theme primary if null)
final
iconColor Color?
Custom icon color (uses theme if null)
final
isExpanded bool
Whether the navigation is currently expanded (showing drawer)
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onToggle VoidCallback
Callback when toggle is pressed
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<VooCollapseToggle>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited