VooContextSwitcher class

Context switcher widget for switching between contexts (projects, workspaces, etc).

This widget displays a card (closed state) that expands to show a dropdown modal (open state) with available contexts. When a context is selected, the navigation items can dynamically change based on the itemsBuilder callback in the config.

Example usage:

VooContextSwitcher(
  config: VooContextSwitcherConfig(
    items: projects,
    selectedItem: currentProject,
    onContextChanged: (project) => setState(() => currentProject = project),
    itemsBuilder: (project) => getItemsForProject(project),
    sectionTitle: 'Projects',
    showSearch: true,
  ),
)
Inheritance

Constructors

VooContextSwitcher({Key? key, required VooContextSwitcherConfig config, bool? compact})
const

Properties

compact bool?
Whether to show in compact mode (icon/avatar only). When null, auto-detects from VooCollapseState in widget tree.
final
config VooContextSwitcherConfig
Configuration for the context switcher
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<VooContextSwitcher>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited