VooMultiSwitcherCardData class

Data passed to custom card builder.

This class provides all the information needed to build a custom card for the multi-switcher's closed state.

Constructors

VooMultiSwitcherCardData({VooOrganization? selectedOrganization, String? userName, String? userEmail, String? avatarUrl, Widget? avatarWidget, String? initials, VooUserStatus? status, required bool isExpanded, bool isLoading = false, required VoidCallback onTap})
const

Properties

avatarUrl → String?
URL for the current user's avatar
final
avatarWidget → Widget?
Custom widget for the avatar
final
hashCode → int
The hash code for this object.
no setterinherited
initials → String?
User initials
final
isExpanded → bool
Whether the modal is currently expanded
final
isLoading → bool
Whether the switcher is in a loading state
final
onTap → VoidCallback
Callback to toggle the modal open/closed
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedOrganization → VooOrganization?
Currently selected organization
final
status → VooUserStatus?
Current user's online status
final
userEmail → String?
Current user's email address
final
userName → String?
Current user's display name
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited