VooMultiSwitcherModalData class

Data passed to custom modal builder.

This class provides all the information needed to build a custom modal for the multi-switcher's open state.

Constructors

VooMultiSwitcherModalData({required List<VooOrganization> organizations, VooOrganization? selectedOrganization, List<VooMultiSwitcherUser>? users, VooMultiSwitcherUser? selectedUser, String? userName, String? userEmail, String? avatarUrl, String? initials, VooUserStatus? status, bool isLoading = false, required VoidCallback onClose, required ValueChanged<VooOrganization> onOrganizationSelected, ValueChanged<VooMultiSwitcherUser>? onUserSelected, VoidCallback? onSettingsTap, VoidCallback? onLogout, VoidCallback? onCreateOrganization, VoidCallback? onAddUser, List<VooProfileMenuItem>? menuItems})
const

Properties

avatarUrl → String?
URL for the current user's avatar
final
hashCode → int
The hash code for this object.
no setterinherited
initials → String?
User initials
final
isLoading → bool
Whether the switcher is in a loading state
final
Custom menu items
final
onAddUser → VoidCallback?
Callback to add a new user
final
onClose → VoidCallback
Callback to close the modal
final
onCreateOrganization → VoidCallback?
Callback to create a new organization
final
onLogout → VoidCallback?
Callback when logout is tapped
final
onOrganizationSelected → ValueChanged<VooOrganization>
Callback when an organization is selected
final
onSettingsTap → VoidCallback?
Callback when settings is tapped
final
onUserSelected → ValueChanged<VooMultiSwitcherUser>?
Callback when a user is selected
final
organizations → List<VooOrganization>
List of available organizations
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedOrganization → VooOrganization?
Currently selected organization
final
selectedUser → VooMultiSwitcherUser?
Currently selected user
final
status → VooUserStatus?
Current user's online status
final
userEmail → String?
Current user's email address
final
userName → String?
Current user's display name
final
users → List<VooMultiSwitcherUser>?
List of available users (for multi-account support)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited