VooNotificationsBellConfig class

Configuration for the notifications bell

Constructors

VooNotificationsBellConfig({required List<VooNotificationItem> notifications, int? unreadCount, ValueChanged<VooNotificationItem>? onNotificationTap, ValueChanged<VooNotificationItem>? onNotificationDismiss, VoidCallback? onMarkAllRead, VoidCallback? onViewAll, int maxVisibleNotifications = 5, bool showMarkAllRead = true, bool showViewAllButton = true, String? emptyStateMessage, VooNotificationsBellStyle? style, bool compact = false, String? tooltip, Widget? emptyStateWidget, Widget? headerWidget, Widget? footerWidget})
const

Properties

compact bool
final
emptyStateMessage String?
final
emptyStateWidget Widget?
final
footerWidget Widget?
final
hashCode int
The hash code for this object.
no setterinherited
headerWidget Widget?
final
maxVisibleNotifications int
final
notifications List<VooNotificationItem>
final
onMarkAllRead VoidCallback?
final
onNotificationDismiss ValueChanged<VooNotificationItem>?
final
onNotificationTap ValueChanged<VooNotificationItem>?
final
onViewAll VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showMarkAllRead bool
final
showViewAllButton bool
final
style VooNotificationsBellStyle?
final
tooltip String?
final
unreadCount int?
final

Methods

copyWith({List<VooNotificationItem>? notifications, int? unreadCount, ValueChanged<VooNotificationItem>? onNotificationTap, ValueChanged<VooNotificationItem>? onNotificationDismiss, VoidCallback? onMarkAllRead, VoidCallback? onViewAll, int? maxVisibleNotifications, bool? showMarkAllRead, bool? showViewAllButton, String? emptyStateMessage, VooNotificationsBellStyle? style, bool? compact, String? tooltip, Widget? emptyStateWidget, Widget? headerWidget, Widget? footerWidget}) VooNotificationsBellConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited