VooQuickActions class

A quick actions menu with customizable trigger

Inheritance

Constructors

VooQuickActions({Key? key, required List<VooQuickAction> actions, IconData? triggerIcon, Widget? triggerWidget, String? tooltip, bool showLabelsInGrid = true, VooQuickActionsStyle? style, bool compact = false, Widget actionBuilder(VooQuickAction, VoidCallback onTap)?, ValueChanged<VooQuickAction>? onActionSelected, bool useGridLayout = false, int gridColumns = 4})
const

Properties

actionBuilder → Widget Function(VooQuickAction, VoidCallback onTap)?
Custom action builder
final
actions → List<VooQuickAction>
List of quick actions
final
compact → bool
Whether to show in compact mode
final
gridColumns → int
Number of columns in grid layout
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onActionSelected → ValueChanged<VooQuickAction>?
Callback when an action is selected
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showLabelsInGrid → bool
Whether to show labels in grid layout
final
style → VooQuickActionsStyle?
Style configuration
final
tooltip → String?
Tooltip for the trigger
final
triggerIcon → IconData?
Icon for the trigger button
final
triggerWidget → Widget?
Custom trigger widget
final
useGridLayout → bool
Whether to use grid layout
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<VooQuickActions>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited