VooContextSwitcherPosition enum
Position of the context switcher in the navigation
Values
- beforeItems → const VooContextSwitcherPosition
-
Before the navigation items (after header/search)
- afterHeader → const VooContextSwitcherPosition
-
After the header section
-
Render as a navigation item in rail/bottom nav. When using this position, the context switcher appears as a nav item with the current context's avatar, and opens a bottom sheet modal on tap.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VooContextSwitcherPosition> - A constant List of the values in this enum, in order of their declaration.