VooNotificationsBell class
A notification bell with dropdown list
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- VooNotificationsBell
Constructors
-
VooNotificationsBell({Key? key, required List<
VooNotificationItem> notifications, int? unreadCount, ValueChanged<VooNotificationItem> ? onNotificationTap, ValueChanged<VooNotificationItem> ? onNotificationDismiss, VoidCallback? onMarkAllRead, VoidCallback? onViewAll, int maxVisibleNotifications = 5, bool showMarkAllRead = true, bool showViewAllButton = true, String? emptyStateMessage, VooNotificationsBellStyle? style, bool compact = false, Widget notificationBuilder(VooNotificationItem, VoidCallback onTap, VoidCallback? onDismiss)?, Widget? emptyStateWidget, Widget? headerWidget, String? tooltip}) -
const
Properties
- compact → bool
-
Whether to show in compact mode
final
- emptyStateMessage → String?
-
Message to show when no notifications
final
- emptyStateWidget → Widget?
-
Custom empty state widget
final
-
Custom footer widget
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerWidget → Widget?
-
Custom header widget
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxVisibleNotifications → int
-
Maximum visible notifications in dropdown
final
- notificationBuilder → Widget Function(VooNotificationItem, VoidCallback onTap, VoidCallback? onDismiss)?
-
Custom notification item builder
final
-
notifications
→ List<
VooNotificationItem> -
List of notifications
final
- onMarkAllRead → VoidCallback?
-
Callback when mark all as read is tapped
final
-
onNotificationDismiss
→ ValueChanged<
VooNotificationItem> ? -
Callback when a notification is dismissed
final
-
onNotificationTap
→ ValueChanged<
VooNotificationItem> ? -
Callback when a notification is tapped
final
- onViewAll → VoidCallback?
-
Callback when view all is tapped
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showMarkAllRead → bool
-
Whether to show mark all as read button
final
- showViewAllButton → bool
-
Whether to show view all button
final
- style → VooNotificationsBellStyle?
-
Style configuration
final
- tooltip → String?
-
Tooltip text
final
- unreadCount → int?
-
Override for unread count badge
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< VooNotificationsBell> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited